/* global Drupal */

// Ensure $ is available: Foundation and select2 need to bind to it
import $ from 'jquery'
import select2 from 'select2'

/* eslint-disable no-unused-vars */
import {
  Accordion,
  Foundation,
  Reveal,
  SmoothScroll,
  Toggler
} from 'foundation-sites/js/foundation'
/* eslint-enable no-unused-vars */

import {
  AdaptiveSticky,
  CookieBar,
  FileUpload,
  SelectTwo,
  Share,
  Slideshow,
  StickyButton,
  ToggleElement,
  UserAgent,
  initEventBridge,
} from '@moreonion/foundation-base'

// Add the select2 to jQuery
// Needed for SelectTwo plugin
select2($)

// Add Foundation to jQuery
Foundation.addToJquery($)

// Configure Foundation
Foundation.plugin(AdaptiveSticky, 'AdaptiveSticky')
Foundation.plugin(CookieBar, 'CookieBar')
Foundation.plugin(FileUpload, 'FileUpload')
Foundation.plugin(SelectTwo, 'SelectTwo')
Foundation.plugin(Slideshow, 'Slideshow')
Foundation.plugin(Share, 'Share')
Foundation.plugin(StickyButton, 'StickyButton')
Foundation.plugin(ToggleElement, 'ToggleElement')
Foundation.plugin(UserAgent, 'UserAgent')

/**
 * Let foundation initialize the initial markup.
 * This needs to be done for dynamically loaded markup too (e.g. AJAX markup)
 */
export function initFoundation () {
  initEventBridge($)
  if (typeof Drupal !== 'undefined') {
    Drupal.behaviors.foundist_initialize = {}
    Drupal.behaviors.foundist_initialize.attach = (context, settings) => {
      $(context).foundation()
      // Show overlays with `data-open` initially.
      const $overlay = $('[data-reveal][data-open]')
      if (context === document && $overlay.length) {
        $overlay.foundation('open')
      }
    }
  } else {
    $(window.document).foundation()
    $(window.document).on('dom-inserted', (event) => {
      $(event.target).foundation()
    })
  }
}

/**
 * Activate AdaptiveSticky on forms in the sidebar.
 * @param {object} options - Overrides to the AdaptiveSticky plugin settings.
 * @returns {AdaptiveSticky|undefined} The initialized AdaptiveSticky plugin
 */
export function stickyForm (options = {}) {
  const $form = $('#sidebar #form, #sidebar .share-buttons')
  if (!$form.length) {
    return
  }
  const $sidebar = $('#sidebar')
  // Add a wrapper around the #sidebar content to make all of it sticky.
  $sidebar.children().wrapAll('<div class="sticky" />')
  // Let the actual form inside #form stick to the window top.
  return new Foundation.AdaptiveSticky($sidebar.children('.sticky'), {
    target: '#form-outer #form, #form-outer .share-buttons ul',
    offset: $('#form-outer').css('padding-top'),
    mediaQuery: 'large',
    ...options
  })
}

/**
 * Activate StickyButton on CTA markup snippet.
 * @param {object} options - Overrides to the StickyButton plugin settings.
 * @returns {StickyButton[]|undefined} Array of initialized StickyButton plugins
 */
export function stickyButton (options = {}) {
  let $cta = $('.sticky-cta')
  if (!$cta.length) {
    return
  }
  const defaults = {
    topOverlap: 0.3
  }
  // Find blocking element
  const target = $cta.find('a').attr('href')
  if (target && !target.includes('/')) {
    defaults.blocker = target
  }
  // Put button(s) in right position.
  // Depending on the layout, the button should be on the bottom of the page,
  // the sidebar or the main wrapper for large screen sizes.
  const $newParent = $('#sidebar, #main > .grid-container > .inner-wrapper')
  if ($newParent.length) {
    const $clone = $cta.clone().appendTo($newParent).addClass('bottom show-for-large')
    $cta.appendTo('#page').addClass('bottom hide-for-large')
    $cta = $cta.add($clone)
  } else {
    $cta.appendTo('#page').addClass('bottom')
  }
  // Add SmoothScroll
  new SmoothScroll($cta.find('a')) // eslint-disable-line no-new
  // Initialize plugin
  return $cta.map((i, el) => {
    return new Foundation.StickyButton($(el), {
      ...defaults,
      ...options
    })
  })
}

/**
 * Activate cookiebar on cookiebar id.
 * @param {object} options - Overrides to the Cookiebar plugin settings.
 * @returns {Cookiebar|undefined} The initialized Cookiebar plugin
 */
export function cookiebar (options = {}) {
  const $cookiebar = $('#cookiebar')
  if (!$cookiebar.length) {
    return
  }
  // Put cookiebar in right position.
  $cookiebar.detach().appendTo('body')
  // Initialize plugin
  return new Foundation.CookieBar($cookiebar, options)
}
